California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 34 - CAMPAIGN CONTRIBUTIONS AND SPENDING. LIMITS. DISCLOSURE. LEGISLATIVE INITIATIVE AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1224774 | CALIFORNIANS AGAINST PHONY "REFORM" - NO ON 34-SPONSORED BY LEAGUE OF WOMEN VOTERS OF CALIFORNIA, AMERICAN ASSOCIATION OF RETIRED PERSONS-CALIFORNIA (AARP), COMMON CAUSE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1225886 | CITIZENS FOR CONSTITUTIONAL CAMPAIGN REFORM, YES ON PROP 34 | SUPPORT